pub enum NodeStatus {
Before,
AfterNewBytes,
AfterOldBytes {
start: u32,
end: u32,
},
}Variants
Before
The node was created before we took the checkpoint, it will still be valid after restoring the allocator state to the checkpoint.
AfterNewBytes
This node was created after we took the checkpoint. It also refers to data that was created after the checkpoint. Every aspect of this node will become invalid after restoring the allocator to the checkpoint.
AfterOldBytes
This node was created after the checkpoint, but it’s referencing data from the heap that was allocated before the checkpoint. This is a case that can happen with substr() on a value from the environment. The node will become invalid, but the underlying data won’t, so we could create a new node referencing the same data, after restoring the allocator to the checkpoint.